@@ -16,6 +16,8 @@ import numpy as np
 import re
 import tifffile as tiff
 
+import os
+from typing import List, Dict, Any
 from AnyQt import QtWidgets, QtGui, QtCore
 from scipy.ndimage import uniform_filter
 # --- CLAHE optionnel via scikit-image ---
@@ -24,7 +26,10 @@ try:
     HAS_SKIMAGE = True
 except Exception:
     HAS_SKIMAGE = False
-
+if "site-packages/Orange/widgets" in os.path.dirname(os.path.abspath(__file__)).replace("\\", "/"):
+    from Orange.widgets.orangecontrib.IMG4IT.utils.reacalage_image import apply_transform_to_image_file
+else:
+    from orangecontrib.IMG4IT.utils.reacalage_image import apply_transform_to_image_file
 
 def qimage_from_gray_uint8(arr_u8: np.ndarray) -> QtGui.QImage:
     """Convertit un ndarray uint8 (H, W) en QImage Grayscale8 sans copie."""
@@ -933,6 +938,12 @@ def _which_op(spec: str) -> str:
         return "crop"
     raise ValueError(f"Unknown operation type in spec header: '{head}'. Expected 'Transform' or 'Crop'.")
 
+def _is_Rt_spec(spec: str) -> bool:
+    """Retourne True si spec contient une matrice R et un vecteur t."""
+    if not isinstance(spec, str):
+        return False
+    return bool(re.search(r"R\s*=\s*\[\[.*?\]\].*t\s*=\s*\[.*?\]", spec, flags=re.I | re.S))
+
 
 def process_tiff_spec(src_path: str, dst_path: str, spec: str,
                       default_he_bins: int = 256, default_clahe_clip: float = 0.01):
@@ -949,6 +960,9 @@ def process_tiff_spec(src_path: str, dst_path: str, spec: str,
 
     Retourne un dict récapitulatif (incluant 'operation': 'transform' ou 'crop').
     """
+    if _is_Rt_spec(spec):
+        return apply_transform_to_image_file(src_path, dst_path, spec)
+
     op = _which_op(spec)
 
     if op == "transform":
@@ -1063,8 +1077,6 @@ def transform_tiff16_to_tiff8(src_path: str, dst_path: str, transform_spec: str,
 
 
 
-import os
-from typing import List, Dict, Any
 
 def batch_process_tiff_folder(
     input_dir: str,
@@ -1126,6 +1138,7 @@ def batch_process_tiff_folder(
             results.append(info)
             processed += 1
         except Exception as e:
+            print(str(e))
             results.append({"src": src, "dst": dst, "ok": False, "error": str(e)})
             failed += 1
 
@@ -1139,6 +1152,88 @@ def batch_process_tiff_folder(
         "results": results,
     }
 
+
+
+def batch_process_tiff_files(
+    input_files: List[str],
+    output_files: List[str],
+    spec: List[str],
+    progress_callback=None,
+    argself=None
+) -> Dict[str, Any]:
+    """
+    Applique `process_tiff_spec` à chaque paire (input_files[i], output_files[i]).
+    Les deux listes doivent être de même longueur.
+
+    Paramètres
+    ----------
+    input_files : List[str]
+        Liste des chemins de fichiers TIFF source.
+    output_files : List[str]
+        Liste des chemins de fichiers TIFF destination (même longueur que input_files).
+    spec : str
+        Chaîne d'opération ("Transform | ..." OU "Crop | ...").
+    default_he_bins : int
+        Paramètre par défaut pour HE/CLAHE si non précisé dans la spec Transform.
+    default_clahe_clip : float
+        Paramètre par défaut pour CLAHE si non précisé dans la spec Transform.
+
+    Retour
+    ------
+    dict : résumé d’exécution, incluant les résultats fichier par fichier.
+    """
+    default_he_bins = 256
+    default_clahe_clip = 0.01
+    if len(input_files) != len(output_files):
+        raise ValueError(f"input_files and output_files must have the same length "
+                         f"({len(input_files)} vs {len(output_files)}).")
+
+    results: List[Dict[str, Any]] = []
+    processed = 0
+    failed = 0
+
+    total = len(input_files)
+    for idx, (src, dst) in enumerate(zip(input_files, output_files), start=0):
+        print(f"process {idx+1}/{total}")
+        if progress_callback is not None:
+            progress_value = float(100 * (idx + 1) /total)
+            progress_callback(progress_value)
+        if argself is not None:
+            if argself.stop:
+                break
+        os.makedirs(os.path.dirname(dst) or ".", exist_ok=True)
+        if os.path.exists(dst):
+            os.remove(dst)
+            print(f"removed existing file: {dst}")
+        try:
+            info = process_tiff_spec(
+                src_path=src,
+                dst_path=dst,
+                spec=spec[idx],
+                default_he_bins=default_he_bins,
+                default_clahe_clip=default_clahe_clip,
+            )
+            if isinstance(info,str):
+                results.append({"src": src, "dst": dst, "ok": True})
+            else:
+                info.update({"src": src, "dst": dst, "ok": True})
+                results.append(info)
+            processed += 1
+        except Exception as e:
+            print("error batch_process_tiff_files ",e)
+            results.append({"src": src, "dst": dst, "ok": False, "error": str(e)})
+            failed += 1
+
+    return {
+        "spec": spec,
+        "total": total,
+        "processed": processed,
+        "failed": failed,
+        "results": results,
+    }
+
+
+
 # read batch_process_tiff_folder !!!
 # usage hors orange
 # from tiff16_viewer import transform_tiff16_to_tiff8
