@@ -88,7 +88,6 @@ class OWPaddleOCR(widget.OWWidget):
                                    show_log=False)
             self.information("Paddle OCR model successfully loaded.")
 
-
     def run(self):
         # if thread is running quit
         if self.thread is not None:
@@ -191,6 +190,9 @@ def apply_OCR(filepath, model):
     Returns:
         dict[int, str]: page_number -> recognized text
     """
+    if not os.exists(filepath):
+        return {-1: "File not found"}
+
     ext = os.path.splitext(filepath)[1].lower()
 
     if ext == ".pdf":
